@@ -144,26 +144,28 @@ void
 CallInitiatorFactory::onAllAccountsReady ()
 {
     bAccountsReady = true;
-    qDebug () << QString("%1 accounts ready").arg (allAccounts.size ());
+    Q_DEBUG (QString("%1 accounts ready").arg (allAccounts.size ()));
 
     bool rv; Q_UNUSED(rv);
     QString msg;
     foreach (Tp::AccountPtr act, allAccounts) {
-        msg = QString ("Account cmName = %1\n").arg (act->cmName ());
-        if ((act->cmName () != "sofiasip") &&
-            (act->cmName () != "spirit") &&
-            (act->cmName () != "ring"))
+        QString cmName = act->cmName ();
+        msg = QString ("Account cmName = %1").arg (cmName);
+        if ((cmName != "sofiasip") &&
+            (cmName != "spirit") &&
+            (cmName != "ring"))
         {
             // Who cares about this one?
-            msg += "\tIGNORED!!";
-            qDebug () << msg;
+            msg += " IGNORED!!";
+            Q_DEBUG (msg);
             continue;
         }
 
         CalloutInitiator *initiator = new TpCalloutInitiator (act, this);
         listInitiators += initiator;
 
-        if (act->cmName () == "ring") {
+        if (cmName == "ring") {
+            Q_DEBUG("Added ring as fallback");
             listFallback += initiator;
         }
 
@@ -173,8 +175,8 @@ CallInitiatorFactory::onAllAccountsReady ()
         rv = connect (initiator, SIGNAL (changed()), this, SIGNAL (changed()));
         Q_ASSERT(rv);
 
-        msg += "\tADDED!";
-        qDebug () << msg;
+        msg += " ADDED!";
+        Q_DEBUG (msg);
     }
 }//CallInitiatorFactory::onAllAccountsReady
 
