@@ -219,10 +219,6 @@ private:
     void initInbox ();
     void deinitInbox ();
 
-    bool getInfoFrom (const QString &strNumber,
-                      const QString &strNameLink,
-                      ContactInfo &info);
-
     bool findInfo (const QString &strNumber, ContactInfo &info);
 
     bool refreshRegisteredNumbers ();
@@ -246,10 +242,10 @@ private:
 
     void initMq();
 
+    //! Get a pointer to the QML object
     QObject * getQMLObject(const char *pageName);
-
     bool ensureNwMgr();
-
+    //! Request quit in the app
     void requestQuit();
 
 private:
